<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>ActivityResultReceiver</name>
    <message>
        <location filename="../android_rtl_sdr.cpp" line="+178"/>
        <source>Android RTL-SDR driver is not installed</source>
        <translation>Le pilote RTL-SDR Android n&apos;est pas installé</translation>
    </message>
</context>
<context>
    <name>AirspySettings</name>
    <message>
        <location filename="../QML/settingpages/AirspySettings.qml" line="+12"/>
        <source>Airspy settings</source>
        <translation>Paramètres Airspy</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Enable bias tee</source>
        <translation>Activer le té de polarisation</translation>
    </message>
</context>
<context>
    <name>CAndroid_RTL_SDR</name>
    <message>
        <location filename="../android_rtl_sdr.cpp" line="-41"/>
        <source>OK</source>
        <translation></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Android RTL-SDR driver is not installed. Do you would like to install it? After install start welle.io again.</source>
        <translation>Le pilote RTL-SDR Android n&apos;est pas installé. Voulez-vous l&apos;installer ? Redémarrez welle.io après l&apos;installation.</translation>
    </message>
</context>
<context>
    <name>CGUIHelper</name>
    <message>
        <location filename="../gui_helper.cpp" line="+66"/>
        <location line="+614"/>
        <source>Mi&amp;nimize</source>
        <translation>Mi&amp;nimiser</translation>
    </message>
    <message>
        <location line="-611"/>
        <location line="+612"/>
        <source>Ma&amp;ximize</source>
        <translation>Ma&amp;ximiser</translation>
    </message>
    <message>
        <location line="-609"/>
        <location line="+610"/>
        <source>&amp;Restore</source>
        <translation>&amp;Restaurer</translation>
    </message>
    <message>
        <location line="-607"/>
        <location line="+608"/>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location line="-504"/>
        <source>welle.io version</source>
        <translation>Version de welle.io</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Built on</source>
        <translation>Compilé le</translation>
    </message>
    <message>
        <source>version</source>
        <translation type="vanished">version</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Git revision</source>
        <translation>Révision Git</translation>
    </message>
    <message>
        <source>Build on</source>
        <translation type="vanished">Compilé le</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>QT version</source>
        <translation>Version QT</translation>
    </message>
    <message>
        <source>The program will keep running in the system tray. To terminate the program, choose &quot;Quit&quot; in the context menu of the system tray entry.</source>
        <translation type="obsolete">Le programme continue de tourner dans la boite à miniatures. Pour le terminer, choisir &quot;Quitter&quot; dans le menu contextuel de la boîte à miniatures.</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>The program will keep running in the system tray. To terminate the program, choose &lt;b&gt;Quit&lt;/b&gt; in the context menu of the system tray entry.</source>
        <translation>Le programme continue de tourner dans la boite à miniatures. Pour le terminer, choisir &quot;Quitter&quot; dans le menu contextuel de la boîte à miniatures.</translation>
    </message>
    <message>
        <location line="+506"/>
        <source> (unavailable, fallback to Default)</source>
        <translation> (non disponible, utilise &quot;Default&quot; à la place)</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Style of system</source>
        <translation>Style du système</translation>
    </message>
    <message>
        <location line="+2"/>
        <source> (Recommended)</source>
        <translation> (Recommandé)</translation>
    </message>
</context>
<context>
    <name>CRadioController</name>
    <message>
        <location filename="../radio_controller.cpp" line="+619"/>
        <source>Unknown</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <location line="-202"/>
        <location line="+221"/>
        <source>No Station</source>
        <translation>Pas de station</translation>
    </message>
    <message>
        <location line="-486"/>
        <source>Error while opening file </source>
        <translation>Erreur à l&apos;ouverture du fichier </translation>
    </message>
    <message>
        <location line="+228"/>
        <source>RAW File</source>
        <translation>Fichier RAW</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+466"/>
        <source>Scanning</source>
        <translation>Recherche</translation>
    </message>
    <message>
        <location line="-462"/>
        <location line="+487"/>
        <source>Found channels</source>
        <translatorcomment>Contexte: nombre stations trouvées durant la recherche de stations en scannant tous les canaux. Donc c&apos;est bien &quot;station&quot; qu&apos;il faut mettre, et pas &quot;canal&quot;</translatorcomment>
        <translation>Stations trouvées</translation>
    </message>
    <message>
        <location line="-271"/>
        <source>Playing last station</source>
        <translation>Lecture de la dernière station</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Radio device is not ready or does not exist.</source>
        <translation>Le récepteur radio n&apos;est pas prêt ou n&apos;existe pas.</translation>
    </message>
    <message>
        <location filename="../../input/airspy_sdr.cpp" line="+152"/>
        <source>airspy is unplugged.</source>
        <translation>Airspay est débranché.</translation>
    </message>
    <message>
        <location filename="../../input/input_factory.cpp" line="+79"/>
        <source>No valid device found use Null device instead.</source>
        <translatorcomment>traduction &quot;null device&quot; ?</translatorcomment>
        <translation type="unfinished">Aucun récepteur valide trouvé. Utilisation de &quot;Null device&quot; à la place.</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+43"/>
        <source>Error while opening device</source>
        <translation>Erreur à l&apos;ouverture du récepteur</translation>
    </message>
    <message>
        <location filename="../../input/raw_file.cpp" line="+177"/>
        <location line="+20"/>
        <source>Cannot open file </source>
        <translation>Ouverture du fichier impossible </translation>
    </message>
    <message>
        <location line="+113"/>
        <source>End of file, restarting</source>
        <translatorcomment>doute sur la traduction de &quot;lecture en boucle&quot;</translatorcomment>
        <translation type="unfinished">Fin du fichier, recommence depuis le début</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End of file</source>
        <translation>Fin du fichier</translation>
    </message>
    <message>
        <location line="+88"/>
        <source>Unknown RAW file format</source>
        <translation>Format de fichier RAW inconnu</translation>
    </message>
    <message>
        <location filename="../../input/rtl_sdr.cpp" line="+294"/>
        <location filename="../../input/rtl_tcp.cpp" line="+462"/>
        <source>ADC overload. Maybe you are using a too high gain.</source>
        <translatorcomment>ADC ou AGC ? Saturation ou Surcharge ? Saturation semble préférable.</translatorcomment>
        <translation type="unfinished">Saturation ADC. Peut-être le gain est trop élevé.</translation>
    </message>
    <message>
        <location line="+96"/>
        <source>RTL-SDR is unplugged.</source>
        <translation>RTL-SDR est débranché.</translation>
    </message>
    <message>
        <location filename="../../input/rtl_tcp.cpp" line="-190"/>
        <source>RTL-TCP connection closed.</source>
        <translation>Connexion RTL-TCP fermée.</translation>
    </message>
    <message>
        <location line="+141"/>
        <source>Connection failed to server </source>
        <translation>Echec de connexion au serveur </translation>
    </message>
    <message>
        <location filename="../../input/soapy_sdr.cpp" line="+91"/>
        <source>Could not load SoapySDR with provided device arguments.</source>
        <translation>Chargement de SoapySDR impossible avec les paramètres de périphérique renseignés.</translation>
    </message>
</context>
<context>
    <name>ChannelSettings</name>
    <message>
        <location filename="../QML/settingpages/ChannelSettings.qml" line="+29"/>
        <source>Automatic start playing last station</source>
        <translation>Lire automatiquement la dernière station</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Display station name in the window title</source>
        <translation>Afficher le nom de la station dans le titre de la fenêtre</translation>
    </message>
</context>
<context>
    <name>ConstellationGraph</name>
    <message>
        <location filename="../QML/expertviews/ConstellationGraph.qml" line="+10"/>
        <source>Constellation Diagram</source>
        <translation>Diagramme de constellation</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>DQPSK Angle [Degree]</source>
        <translation>Angle DQPSK [degrés]</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Subcarrier</source>
        <translation>Sous-porteuse</translation>
    </message>
</context>
<context>
    <name>DABConstants</name>
    <message>
        <location filename="../../backend/dab-constants.cpp" line="+184"/>
        <source>News</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)
</translatorcomment>
        <translation>Informations</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Current Affairs</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Magazine</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Information</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Info-Service</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sport</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Sport</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Education</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Educatif</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drama</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Fiction</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arts</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Culture</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Science</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Sciences</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Talk</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Divertissement</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pop Music</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Musique Pop</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rock Music</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Musique Rock</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Easy Listening</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Chansons</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light classical</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Classique Léger</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Classical Music</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>MusiqueClassique</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Other Music</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Autre Musique</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Weather</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Météo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Finance</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Economie</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Children&apos;s</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Enfants</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Factual</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Société</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Religion</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Religion</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Phone In</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Ligne ouverte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Travel</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Voyages</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Leisure</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Loisirs</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Jazz and Blues</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Jazz</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Country Music</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Country</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>National Music</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Chanson du pays</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Oldies Music</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Musique rétro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Folk Music</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Folklore</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Documentary</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>Documentaire</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>entry 30 not used</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>non utilisé (30)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>entry 31 not used</source>
        <translatorcomment>ETSI TS 101 756 V2.2.1 (2017-08) (page 23)</translatorcomment>
        <translation>non utilisé (31)</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+117"/>
        <source>UNKNOWN</source>
        <translation>Inconnu</translation>
    </message>
    <message>
        <location line="-103"/>
        <source>Albanian</source>
        <translation>Albanais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Breton</source>
        <translation>Breton</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Catalan</source>
        <translation>Catalan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Croatian</source>
        <translation>Croate</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Welsh</source>
        <translation>Gallois</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Czech</source>
        <translation>Tchèque</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Danish</source>
        <translation>Danois</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>German</source>
        <translation>Allemand</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>English</source>
        <translation>Anglais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Spanish</source>
        <translation>Espagnol</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Esperanto</source>
        <translation>Esperanto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Estonian</source>
        <translation>Estonien</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Basque</source>
        <translation>Basque</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Faroese</source>
        <translation>Féroïen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>French</source>
        <translation>Français</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frisian</source>
        <translation>Frison</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Irish</source>
        <translation>Irlandais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gaelic</source>
        <translation>Gaélique</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Galician</source>
        <translation>Galicien</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Icelandic</source>
        <translation>Islandais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italian</source>
        <translation>Italien</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lappish</source>
        <translation>Lapon</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Latin</source>
        <translation>Latin</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Latvian</source>
        <translation>Letton</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Luxembourgian</source>
        <translation>Luxembourgeois</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Lithuanian</source>
        <translation>Lituanien</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hungarian</source>
        <translation>Hongrois</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Maltese</source>
        <translation>Maltais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dutch</source>
        <translation>Néerlandais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Norwegian</source>
        <translation>Norvégien</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Occitan</source>
        <translation>Occitan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Polish</source>
        <translation>Polonais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Portuguese</source>
        <translation>Portugais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Romanian</source>
        <translation>Roumain</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Romansh</source>
        <translation>Romanche</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Serbian</source>
        <translation>Serbe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Slovak</source>
        <translation>Slovaque</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Slovene</source>
        <translation>Slovène</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Finnish</source>
        <translation>Finnois</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Swedish</source>
        <translation>Suédois</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Turkish</source>
        <translation>Turc</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Flemish</source>
        <translation>Flamand</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Walloon</source>
        <translation>Wallon</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Background sound/clean feed</source>
        <translation>Son d&apos;arrière plan / Flux propre</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zulu</source>
        <translation>Zoulou</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vietnamese</source>
        <translation>Vietnamien</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Uzbek</source>
        <translation>Ouzbek</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Urdu</source>
        <translation>Ourdou</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ukranian</source>
        <translation>Ukrainien</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Thai</source>
        <translation>Thaï</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Telugu</source>
        <translation>Télougou</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tatar</source>
        <translation>Tatar</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tamil</source>
        <translation>Tamoul</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tadzhik</source>
        <translation>Tadjik</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Swahili</source>
        <translation>Swahili</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sranan Tongo</source>
        <translation>Sranan tongo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Somali</source>
        <translation>Somali</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Sinhalese</source>
        <translation>Cingalais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Shona</source>
        <translation>Shona</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Serbo-Croat</source>
        <translation>Serbo-croate</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rusyn</source>
        <translation>Rusyn</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Russian</source>
        <translation>Russe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Quechua</source>
        <translation>Quechua</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pushtu</source>
        <translation>Pachto</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Punjabi</source>
        <translation>Pendjabi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Persian</source>
        <translation>Persan</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Papiamento</source>
        <translation>Papiamento</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Oriya</source>
        <translation>Oriya</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Nepali</source>
        <translation>Népalais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ndebele</source>
        <translation>Ndébélé</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Marathi</source>
        <translation>Marathi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Moldavian</source>
        <translation>Moldave</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Malaysian</source>
        <translation>Malais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Malagasay</source>
        <translation>Malgache</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Macedonian</source>
        <translation>Macédonien</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Laotian</source>
        <translation>Lao</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Korean</source>
        <translation>Coréen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Khmer</source>
        <translation>Khmer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Kazakh</source>
        <translation>Kazakh</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Kannada</source>
        <translation>Kannada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Japanese</source>
        <translation>Japonais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Indonesian</source>
        <translation>Indonésien</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hindi</source>
        <translation>Hindi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hebrew</source>
        <translation>Hébreu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hausa</source>
        <translation>Haoussa</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gurani</source>
        <translation>Gurani</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gujurati</source>
        <translation>Gujarati</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Greek</source>
        <translation>Grec</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Georgian</source>
        <translation>Géorgien</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fulani</source>
        <translation>Peul</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dari</source>
        <translation>Dari</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Chuvash</source>
        <translation>Tchouvache</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Chinese</source>
        <translation>Chinois</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Burmese</source>
        <translation>Birman</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bulgarian</source>
        <translation>Bulgare</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bengali</source>
        <translation>Bengali</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Belorussian</source>
        <translation>Biélorusse</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bambora</source>
        <translation>Bambara</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Azerbaijani</source>
        <translation>Azéri</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Assamese</source>
        <translation>Assamais</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Armenian</source>
        <translation>Arménien</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arabic</source>
        <translation>Arabe</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Amharic</source>
        <translation>Amharique</translation>
    </message>
</context>
<context>
    <name>ExpertSettings</name>
    <message>
        <location filename="../QML/settingpages/ExpertSettings.qml" line="+33"/>
        <source>Global</source>
        <translation>Global</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Expert mode</source>
        <translation>Mode expert</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Backend</source>
        <translation type="unfinished">Sous-système (Backend)</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Enable coarse corrector (for receivers with &gt;1kHz error)</source>
        <translatorcomment>coarse corrector = correction grossière ?</translatorcomment>
        <translation type="unfinished">Activer la correction grossière (pour récepteurs avec erreur &gt;1kHz)</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>GetMiddle</source>
        <translatorcomment>doute sur la traduction : &quot;Obtenir le milieu ?&quot; Moyen ? Centre</translatorcomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>CorrelatePRS</source>
        <translatorcomment>doute sur la traduction : &quot;Corréler PRS&quot;</translatorcomment>
        <translation type="unfinished">Corréler PRS</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>PatternOfZeros</source>
        <translatorcomment>doute sur la traduction : &quot;Motif de zéros&quot;</translatorcomment>
        <translation type="unfinished">Motif de zéros</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Coarse corrector algorithm</source>
        <translatorcomment>coarse corrector = correction grossière ?</translatorcomment>
        <translation type="unfinished">Algorithme de correction grossière</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Enable TII decoding to console log (increases CPU usage)</source>
        <translation>Activer le décodage TII vers le log de la console (augmente l&apos;utilisation CPU)</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Strongest Peak</source>
        <translatorcomment>doute sur la traduction : &quot;Pic le plus fort&quot; pour Peak utiliser Crête ou Pic</translatorcomment>
        <translation type="unfinished">Crête la plus forte</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Earliest Peak With Binning</source>
        <translatorcomment>doute sur la traduction pour Peak utiliser Crête ou Pic. Pour binning: Compartimentage</translatorcomment>
        <translation type="unfinished">Crête la plus tôt avec compartimentage</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Threshold Before Peak</source>
        <translatorcomment>doute sur la traduction : &quot;Seuil avant pic&quot; pour Peak utiliser Crête ou Pic. Pour threshold : Seuil</translatorcomment>
        <translation type="unfinished">Seuil avant crête</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>FFT Window placement algorithm</source>
        <translation>Algorithme de placement de la fenêtre FFT</translation>
    </message>
</context>
<context>
    <name>GlobalSettings</name>
    <message>
        <location filename="../QML/settingpages/GlobalSettings.qml" line="+68"/>
        <source>Global settings</source>
        <translation>Paramètres globaux</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Full screen mode</source>
        <translation>Mode plein écran</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Language</source>
        <translation>Langue</translation>
    </message>
    <message>
        <location line="+148"/>
        <source>Light</source>
        <translation>Clair</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark</source>
        <translation>Sombre</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Theme</source>
        <translation>Thème</translation>
    </message>
    <message>
        <location line="-147"/>
        <source>Global receiver settings</source>
        <translation>Paramètres globaux du récepteur</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Automatic RF gain</source>
        <translation>Gain RF automatique</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Manual gain</source>
        <translation>Gain RF manuel</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Value: </source>
        <translation>Valeur : </translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Auto detect</source>
        <translation>Détection automatique</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Airspy</source>
        <translation></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>SoapySDR</source>
        <translation></translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Style settings</source>
        <translation>Paramètres de style</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Style changed. Please restart welle.io</source>
        <translation>Style changé. Veuillez redémarrer welle.io</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Style. Restart to apply.</source>
        <translation>Style. Redémarrez pour appliquer.</translation>
    </message>
    <message>
        <location line="-60"/>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>rtl-sdr</source>
        <translatorcomment>minuscules ? majuscules ? Mis en majuscules pour harmoniser tout le logiciel</translatorcomment>
        <translation type="unfinished">RTL-SDR</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>rtl-tcp</source>
        <translatorcomment>minuscules ? majuscules ? Mis en majuscules pour harmoniser tout le logiciel</translatorcomment>
        <translation type="unfinished">RTL-TCP</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>RAW file</source>
        <translation>Fichier RAW</translation>
    </message>
</context>
<context>
    <name>ImpulseResponseGraph</name>
    <message>
        <location filename="../QML/expertviews/ImpulseResponseGraph.qml" line="+12"/>
        <source>Impulse Response</source>
        <translation>Réponse impulsionnelle</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Amplitude</source>
        <translation>Amplitude</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Samples</source>
        <translation>Echantillon</translation>
    </message>
</context>
<context>
    <name>InfoPage</name>
    <message>
        <location filename="../QML/InfoPage.qml" line="+21"/>
        <source>Versions</source>
        <translation>Versions</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Authors</source>
        <translation>Auteurs</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Thanks</source>
        <translation>Remerciements</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Licenses</source>
        <translation>Licences</translation>
    </message>
</context>
<context>
    <name>MainView</name>
    <message>
        <location filename="../QML/MainView.qml" line="+172"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Expert Settings</source>
        <translation>Paramètres expert</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>About</source>
        <translation>A propos de</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Exit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>All stations</source>
        <translation>Toutes les stations</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Favorites</source>
        <translation>Favoris</translation>
    </message>
    <message>
        <location line="+34"/>
        <source>Start station scan</source>
        <translation>Rechercher les stations</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Stop station scan</source>
        <translation>Arrêter la recherche</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Clear station list</source>
        <translation>Effacer la liste des stations</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Station settings</source>
        <translation>Paramètres des stations</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>No stations in list</source>
        <translation>Pas de stations dans la liste</translation>
    </message>
    <message>
        <location line="+108"/>
        <source>Manual channel</source>
        <translation>Canal manuel</translation>
    </message>
    <message>
        <location line="+55"/>
        <source>Service Overview</source>
        <translation>Aperçu du service</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Service Details</source>
        <translation>Détails du service</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>MOT Slide Show</source>
        <translation>Diaporama MOT</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Spectrum</source>
        <translation>Spectre</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Impulse Response</source>
        <translation>Réponse impulsionnelle</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Constellation Diagram</source>
        <translation>Diagramme de constellation</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Null Symbol</source>
        <translatorcomment>?</translatorcomment>
        <translation>Null Symbol</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Console Output</source>
        <translation>Sortie console</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>RAW Recorder</source>
        <translation>Enregistreur RAW I/Q</translation>
    </message>
</context>
<context>
    <name>MotView</name>
    <message>
        <location filename="../QML/MotView.qml" line="+10"/>
        <source>MOT Slide Show</source>
        <translation>Diaporama MOT</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Save all images</source>
        <translation>Sauvegarder toutes les images</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Latest</source>
        <translation>Le plus récent</translation>
    </message>
</context>
<context>
    <name>NullSymbolGraph</name>
    <message>
        <location filename="../QML/expertviews/NullSymbolGraph.qml" line="+10"/>
        <source>Null Symbol</source>
        <translatorcomment>Traduction de NULL selon : TERMIUM Plus®. Mais peut etre laisser tel quel car Null Symbol a un sens précis dans le signal DAB+</translatorcomment>
        <translation type="unfinished">Null Symbol</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Amplitude</source>
        <translation>Amplitude</translation>
    </message>
</context>
<context>
    <name>RTLSDRSettings</name>
    <message>
        <location filename="../QML/settingpages/RTLSDRSettings.qml" line="+12"/>
        <source>rtl-sdr settings</source>
        <translation>Paramètres RTL-SDR</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Enable bias tee (not from all dongles supported)</source>
        <translation>Activer le té de polarisation (non pris en charge par tous les récepteurs)</translation>
    </message>
</context>
<context>
    <name>RTLTCPSettings</name>
    <message>
        <location filename="../QML/settingpages/RTLTCPSettings.qml" line="+11"/>
        <source>rtl-tcp settings</source>
        <translation>Paramètres RTL-TCP</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Use host name</source>
        <translatorcomment>nom d&apos;hôte est la traduction suggérée par TERMIUM Plus®</translatorcomment>
        <translation>Utiliser le nom d&apos;hôte</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>IP address</source>
        <translation>Adresse IP</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>IP port</source>
        <translation>Port IP</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Enter host name</source>
        <translatorcomment>nom d&apos;hôte est la traduction suggérée par TERMIUM Plus®</translatorcomment>
        <translation>Saisir le nom d&apos;hôte</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Host name</source>
        <translation>Nom d&apos;hôte</translation>
    </message>
</context>
<context>
    <name>RadioView</name>
    <message>
        <location filename="../QML/RadioView.qml" line="+13"/>
        <source>Service Overview</source>
        <translation>Aperçu du service</translation>
    </message>
    <message>
        <location line="+27"/>
        <location line="+5"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Toggle volume slider</source>
        <translation type="unfinished">Afficher/cacher le curseur du volume</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Volume set to %1</source>
        <translation>Volume fixé à %1</translation>
    </message>
    <message>
        <location line="+128"/>
        <location line="+5"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location line="-5"/>
        <location line="+5"/>
        <source>Play</source>
        <translation>Lecture</translation>
    </message>
    <message>
        <location line="-4"/>
        <source>Stop playback</source>
        <translation>Arrêter la lecture</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Start playback</source>
        <translation>Démarrer la lecture</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Playback stopped</source>
        <translation>Lecture arrêtée</translation>
    </message>
    <message>
        <source>Last played station not found.
Select a station to start playback.</source>
        <translation type="obsolete">Dernière station lue non trouvée.
Sélectionnez une station pour démarrer la lecture.</translation>
    </message>
</context>
<context>
    <name>RawFileSettings</name>
    <message>
        <location filename="../QML/settingpages/RawFileSettings.qml" line="+12"/>
        <source>RAW file settings</source>
        <translation>Paramètres du fichier RAW</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Open RAW file</source>
        <translation>Ouvrir le fichier RAW</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Currently shown under Android</source>
        <translation>Actuellement affiché sur Android</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Selected file:</source>
        <translation>Fichier sélectionné :</translation>
    </message>
</context>
<context>
    <name>RawRecorder</name>
    <message>
        <location filename="../QML/expertviews/RawRecorder.qml" line="+11"/>
        <source>I/Q RAW Recorder (experimental)</source>
        <translation>Enregistreur RAW I/Q (expérimental)</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Ring buffer length [s]</source>
        <translation>Longueur du buffer circulaire [s]</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Save ring buffer</source>
        <translation type="unfinished">Sauvegarder le buffer circulaire</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Init</source>
        <translatorcomment>?</translatorcomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Ring buffer size (roughly): </source>
        <translatorcomment>Un peu trop long ?</translatorcomment>
        <translation type="unfinished">Taille du buffer circulaire (grosso-modo) : </translation>
    </message>
</context>
<context>
    <name>ServiceDetails</name>
    <message>
        <location filename="../QML/expertviews/ServiceDetails.qml" line="+10"/>
        <source>Service Details</source>
        <translation>Détails du service</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Device</source>
        <translation>Récepteur</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Current channel</source>
        <translatorcomment>une ancienne traduction proposait Bloc actuel</translatorcomment>
        <translation>Canal actuel</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Frame sync</source>
        <translatorcomment>pluriel ?</translatorcomment>
        <translation>Synchronisation de trame</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+15"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location line="-15"/>
        <source>Not synced</source>
        <translation>Pas de sync.</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>FIC CRC</source>
        <translation>FIC CRC</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Frame errors</source>
        <translatorcomment>pluriel ?</translatorcomment>
        <translation>Erreurs de trame</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Frequency correction</source>
        <translation>Correction de fréquence</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>SNR</source>
        <translation>SNR (rapport signal/bruit)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>RS errors</source>
        <translation>Erreurs RS</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>AAC errors</source>
        <translation>Erreurs AAC</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>DAB date and time</source>
        <translation>Date et heure DAB</translation>
    </message>
</context>
<context>
    <name>SoapySDRSettings</name>
    <message>
        <location filename="../QML/settingpages/SoapySDRSettings.qml" line="+11"/>
        <source>SoapySDR settings</source>
        <translation>Paramètres SoapySDR</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Antenna</source>
        <translation>Antenne</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Enter antenna</source>
        <translation>Entrer l&apos;antenne</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Clock source</source>
        <translation>Source d&apos;horloge</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Enter clock source</source>
        <translation>Entrer la source d&apos;horloge</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Driver arguments</source>
        <translation>Arguments du pilote</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Enter driver arguments</source>
        <translation>Entrer les arguments du pilote</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
</context>
<context>
    <name>SpectrumGraph</name>
    <message>
        <location filename="../QML/expertviews/SpectrumGraph.qml" line="+12"/>
        <source>Spectrum</source>
        <translation>Spectre</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Amplitude</source>
        <translation>Amplitude</translation>
    </message>
</context>
<context>
    <name>StationListModel</name>
    <message>
        <location filename="../QML/components/StationListModel.qml" line="+91"/>
        <source>Last played station not found.
Select a station to start playback.</source>
        <translation>Dernière station lue non trouvée.
Sélectionnez une station pour démarrer la lecture.</translation>
    </message>
</context>
<context>
    <name>TextOutputView</name>
    <message>
        <location filename="../QML/expertviews/TextOutputView.qml" line="+11"/>
        <source>Console Output</source>
        <translation>Sortie console</translation>
    </message>
    <message>
        <location line="+58"/>
        <source>Warning: The console view can slow down the complete app!</source>
        <translation>Avertissement: la sortie console peut ralentir toute l&apos;appli !</translation>
    </message>
</context>
<context>
    <name>ViewBaseFrame</name>
    <message>
        <location filename="../QML/components/ViewBaseFrame.qml" line="+122"/>
        <source>Minimize</source>
        <translation>Minimiser</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Maximize</source>
        <translation>Maximiser</translation>
    </message>
    <message>
        <location line="+9"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
</context>
<context>
    <name>WDialog</name>
    <message>
        <location filename="../QML/components/WDialog.qml" line="+32"/>
        <source>‹</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>WSpectrum</name>
    <message>
        <location filename="../QML/components/WSpectrum.qml" line="+15"/>
        <source>Amplitude</source>
        <translation>Amplitude</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frequency</source>
        <translation>Fréquence</translation>
    </message>
    <message>
        <location line="+23"/>
        <source>Waterfall</source>
        <translatorcomment>Adapté de la traduction &quot;WATERFALL DISPLAY&quot; proposée par TERMIUM Plus®</translatorcomment>
        <translation type="unfinished">Ecriture ligne par ligne</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>experimental</source>
        <translation>expérimental</translation>
    </message>
    <message>
        <location line="+62"/>
        <source>Sensitivity</source>
        <translation>Sensibilité</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="+100"/>
        <source>Records DAB frames (*.mp2) or DAB+ superframes with RS coding (*.dab). This file can be used to analyse X-PAD data with XPADxpert</source>
        <translation>Enregistre les trames DAB (*.mp2) ou les supertrames DAB+ avec codage RS (*.dab). Ce fichier peut être utilisé pour analyser des données X-PAD avec XPADxpert</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+5"/>
        <source>File name</source>
        <translation>Nom de fichier</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Redirects all log output texts to a file.</source>
        <translatorcomment>J&apos;ai utilisé &quot;journal&quot; pour la traduction de &quot;log&quot; tel que proposé par TERMIUM Plus®</translatorcomment>
        <translation type="unfinished">Rediriger le journal de sortie vers un fichier.</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Qt Quick Controls Style for the 1st launch</source>
        <translation>Style Qt Quick Controls pour le 1er lancement</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>style_name</source>
        <translation>nom_du_style</translation>
    </message>
</context>
</TS>
